Change condition under which 'retain'/'copy' are directly evaluated.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@60729 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CGObjC.cpp b/lib/CodeGen/CGObjC.cpp
index e95d8e1..845d5ff 100644
--- a/lib/CodeGen/CGObjC.cpp
+++ b/lib/CodeGen/CGObjC.cpp
@@ -148,11 +148,13 @@
   StartObjCMethod(OMD);
 
   // Determine if we should use an objc_getProperty call for
   // this. Non-atomic and properties with assign semantics are
   // directly evaluated, and in gc-only mode we don't need it at all.
   if (CGM.getLangOptions().getGCMode() != LangOptions::GCOnly &&
-      PD->getSetterKind() != ObjCPropertyDecl::Assign &&
-      !(PD->getPropertyAttributes() & ObjCPropertyDecl::OBJC_PR_nonatomic)) {
+      !(PD->getPropertyAttributes() & ObjCPropertyDecl::OBJC_PR_nonatomic) &&
+      (PD->getSetterKind() == ObjCPropertyDecl::Copy ||
+       PD->getSetterKind() == ObjCPropertyDecl::Retain)) {
     llvm::Value *GetPropertyFn = 
       CGM.getObjCRuntime().GetPropertyGetFunction();
@@ -148,11 +148,13 @@
 
   // Determine if we should use an objc_getProperty call for
-  // this. Non-atomic and properties with assign semantics are
-  // directly evaluated, and in gc-only mode we don't need it at all.
+  // this. Non-atomic properties are directly evaluated.
+  // atomic 'copy' and 'retain' properties are also directly
+  // evaluated in gc-only mode.
   if (CGM.getLangOptions().getGCMode() != LangOptions::GCOnly &&